Boltlight contributors, in chronological order of contribution:

* [Zoe Faltibà](https://gitlab.com/zoedberg) - zoefaltiba@gmail.com
* [Nicola Busanello](https://gitlab.com/nicbus) - nicola.busanello@gmail.com
* [Stefano Pellegrini](https://gitlab.com/St333p) - ste.pelle.95@gmail.com


Lighter contributors, in chronological order of contribution:

* [Zoe Faltibà](https://gitlab.com/zoedberg) - zoe@inbitcoin.it
* [Nicola Busanello](https://gitlab.com/dieeasy) - sudo@inbitcoin.it
* [Antonio Parrella](https://gitlab.com/zidagar) - zidagar@inbitcoin.it
* [Marco Amadori](https://gitlab.com/mammadori) - amadori@inbitcoin.it
* [Stefano Pellegrini](https://gitlab.com/St333p) - ste.pelle.95@gmail.com
* [Simone Da Re](https://gitlab.com/siimone) - sdrsdr.dare@gmail.com
